==> neo4j-kernel-api-5.2.0-sources.jar: org/neo4j/internal/kernel/api/security/LabelSegment.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.internal.kernel.api.security;

import java.util.Objects;

public class LabelSegment implements Segment {
    private final String label;

    public LabelSegment(String label) {
        this.label = label;
    }

    public String getLabel() {
        return label;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        LabelSegment that = (LabelSegment) o;

        return Objects.equals(label, that.label);
    }

    @Override
    public int hashCode() {
        return label != null ? label.hashCode() : 0;
    }

    @Override
    public String toString() {
        return String.format("NODE %s", label == null ? "*" : label);
    }

    @Override
    public boolean satisfies(Segment segment) {
        if (segment instanceof LabelSegment other) {
            return label == null || label.equals(other.label);
        }
        return false;
    }

    public static final LabelSegment ALL = new LabelSegment(null);
}

==> neo4j-kernel-api-5.26.9-sources.jar: org/neo4j/internal/kernel/api/security/LabelSegment.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.internal.kernel.api.security;

import org.neo4j.internal.helpers.NameUtil;

public record LabelSegment(String label) implements Segment {

    @Override
    public boolean satisfies(Segment segment) {
        if (segment instanceof LabelSegment other) {
            return label == null || label.equals(other.label);
        }
        return false;
    }

    @Override
    public String toCypherSnippet() {
        if (label == null) {
            return "NODE *";
        } else {
            return String.format("NODE %s", NameUtil.escapeName(label));
        }
    }

    @Override
    public String toString() {
        return String.format("NODE(%s)", nullToStar(label));
    }

    public static final LabelSegment ALL = new LabelSegment(null);
}
